@@ -26,13 +26,13 @@ class NotParseableError(Exception):
 class ClosesIssueParseException(ParseFatalException):
     """Github closes issue string not parseable."""
 
-    def __init__(self, line, loc, message, string):
+    def __init__(self, string, loc, msg=None, elem=None):
         """Initialize a ``ClosesIssueParseException``."""
-        super().__init__(line, loc, message)
-        self.line = line
-        self.loc = loc
-        self.message = message
+        super().__init__(string, loc, msg=msg, elem=elem)
         self.string = string
+        self.loc = loc
+        self.msg = msg
+        self.elem = elem
 
     def __str__(self):
         """Stringify a ``ClosesIssueParseException``."""
@@ -53,10 +53,10 @@ class ClosesIssueParseException(ParseFatalException):
         """Reproduce a ``ClosesIssueParseException``."""
         return (
             "ClosesIssueParseException("
-            f"line={repr(self.line)},"
+            f"string={repr(self.string)},"
             f" loc={repr(self.loc)},"
-            f" message={repr(self.message)},"
-            f" string={repr(self.string)},"
+            f" msg={repr(self.msg)},"
+            f" elem={repr(self.elem)},"
             ")"
         )
 
@@ -121,3 +121,33 @@ class BodyLengthError(ValueError):
             f" message={repr(self.message)},"
             ")"
         )
+
+
+class BreakingLengthError(ValueError):
+    """Breaking change description length error."""
+
+    def __init__(self, longest, max_length):
+        """Initialize a ``BreakingLengthError``."""
+        message = (
+            f"Commit breaking change length ({longest}) exceeds"
+            f" the maximum length ({max_length})."
+        )
+
+        super().__init__(message)
+        self.longest = longest
+        self.max_length = max_length
+        self.message = message
+
+    def __str__(self):
+        """Stringify a ``BreakingLengthError``."""
+        return self.message
+
+    def __repr__(self):
+        """Reproduce a ``BreakingLengthError``."""
+        return (
+            "BreakingLengthError("
+            f"longest={repr(self.longest)},"
+            f" max_length={repr(self.max_length)},"
+            f" message={repr(self.message)},"
+            ")"
+        )
